emacs-diffs
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

master 0d7d09b: Test for error with multibyte strings in bindat.el


From: Stefan Kangas
Subject: master 0d7d09b: Test for error with multibyte strings in bindat.el
Date: Thu, 22 Oct 2020 09:20:27 -0400 (EDT)

branch: master
commit 0d7d09b0ef1b3a939422d273be2fa348e8a148c8
Author: Stefan Kangas <stefan@marxist.se>
Commit: Stefan Kangas <stefan@marxist.se>

    Test for error with multibyte strings in bindat.el
    
    * test/lisp/emacs-lisp/bindat-tests.el
    (bindat-test-pack/multibyte-string-fails)
    (bindat-test-unpack/multibyte-string-fails): New tests.
---
 test/lisp/emacs-lisp/bindat-tests.el | 10 ++++++++--
 1 file changed, 8 insertions(+), 2 deletions(-)

diff --git a/test/lisp/emacs-lisp/bindat-tests.el 
b/test/lisp/emacs-lisp/bindat-tests.el
index 14f95a8..0fb1955 100644
--- a/test/lisp/emacs-lisp/bindat-tests.el
+++ b/test/lisp/emacs-lisp/bindat-tests.el
@@ -1,4 +1,4 @@
 ;;; bindat-tests.el --- tests for bindat.el  -*- lexical-binding: t; -*-
utf-8; -*-
 
 ;; Copyright (C) 2019-2020 Free Software Foundation, Inc.
 
@@ -94,7 +94,13 @@
               (src-ip .
                      [192 168 1 101])
               (dest-ip .
-                      [192 168 1 100]))))))
+                       [192 168 1 100]))))))
+
+(ert-deftest bindat-test-pack/multibyte-string-fails ()
+  (should-error (bindat-pack nil nil (decode-coding-string "ö" 'utf-8))))
+
+(ert-deftest bindat-test-unpack/multibyte-string-fails ()
+  (should-error (bindat-unpack nil (decode-coding-string "ö" 'utf-8))))
 
 (ert-deftest bindat-test-format-vector ()
   (should (equal (bindat-format-vector [1 2 3] "%d" "x" 2) "1x2"))
@@ -1,4 +1,4 @@
-;;; bindat-tests.el --- tests for bindat.el  -*- lexical-binding: t; -*-
+;;; bindat-tests.el --- tests for bindat.el  -*- lexical-binding: t; coding: 
utf-8; -*-
 



reply via email to

[Prev in Thread] Current Thread [Next in Thread]